#!/bin/bash


function helper()
{
	echo "Usage: "
	echo "  ./agent_smart_tool.sh -u cloud_name -p cloud_passwd"
	echo "  ./agent_smart_tool.sh -l port"
	echo "  ./agent_smart_tool.sh -i port"
	echo "  ./agent_smart_tool.sh -d"
	echo "  ./agent_smart_tool.sh -P proxy_server_ip"
	echo "  ./agent_smart_tool.sh -A old:new"
	echo "  ./agent_smart_tool.sh -M"	
	echo "Options:"
	echo "  -u: Cloud center user name"
	echo "  -p: Cloud center password"	
	echo "  -l: Update the listening port of the agent process"
	echo "  -i: Insert the listening port of the agent process"
	echo "  -d: Delete the listening port of the agent process"
	echo "  -P: update proxy server ip"
	echo "  -A: create a special apache's plug-in module"
	echo "  -M: create a new machine id"
	echo "  -h: helper for agent_smart_tool"
}

function bind_cloud_account()
{
	uname=$1
	passwd=$2

	env -i LD_LIBRARY_PATH=$yunsuo_root_path $yunsuo_root_path/register_cloud_center bind $uname $passwd
	exit $?
}

function update_listen_port()
{
	port=$1

	/etc/init.d/$auto_script stop 2&> /dev/null
	
	env -i LD_LIBRARY_PATH=$yunsuo_root_path $yunsuo_root_path/change_port -u $port
	if [ $? -lt 0 ];then
		echo "[ERROR]: Update the listening port failed"
	fi

	/etc/init.d/$auto_script start 2&> /dev/null
}

function delete_listen_port()
{
	/etc/init.d/$auto_script stop 2&> /dev/null

	env -i LD_LIBRARY_PATH=$yunsuo_root_path $yunsuo_root_path/change_port -d
	if [ $? -lt 0 ];then
		echo "[ERROR]: Delete the listening port failed"
	fi

	/etc/init.d/$auto_script start 2&> /dev/null
}

function insert_listen_port()
{
	port=$1

	/etc/init.d/$auto_script stop 2&> /dev/null

	env -i LD_LIBRARY_PATH=$yunsuo_root_path $yunsuo_root_path/change_port -i $port
	if [ $? -lt 0 ];then
		echo "[ERROR]: Add the listening port failed"
	fi

	/etc/init.d/$auto_script start 2&> /dev/null
}

function update_proxy_server()
{
	ip=$1

	/etc/init.d/$auto_script stop 2&> /dev/null
	
	env -i LD_LIBRARY_PATH=$yunsuo_root_path $yunsuo_root_path/change_port -p $ip
	if [ $? -lt 0 ];then
		echo "[ERROR]: Update Proxy Server failed"
	fi

	/etc/init.d/$auto_script start 2&> /dev/null
}

function create_special_apache_module()
{
	old_version=$1
	new_version=$2
	
	old_file=yunsuo_apache_filter_$old_version.so
	new_file=yunsuo_apache_filter_$new_version.so
	
	cp $yunsuo_root_path/apache/$old_file $yunsuo_root_path/apache/$new_file
	echo "$new_version" >> $yunsuo_root_path/apache/support
}

$cloud_name
$cloud_passwd
$update_port
$insert_port
$proxy_ip
$delete_port
$apache_version
$new_machine_id

function parse_command_options()
{
	if [ $# == 0 ];then
		helper
		exit
	fi

	while getopts "u:p:l:i:P:A:dMh" opt
	do
		case $opt in
			u)	cloud_name=$OPTARG
				;;
			p)	cloud_passwd=$OPTARG
				;;
			l)	update_port=$OPTARG
				;;
			d)	delete_port=1
				;;
			i)	insert_port=$OPTARG
				;;
			P)	proxy_ip=$OPTARG
				;;
			A)	apache_version=$OPTARG
				;;
			M)	new_machine_id=1
				;;
			h)	# 帮助信息
				helper
				exit
				;;
			?)	# 未知参数
				helper
				exit
				;;
		esac
	done
}


yunsuo_root_path=`cat /var/log/version_control`
auto_script=`cat $yunsuo_root_path/command_control | grep script_server | awk '{print $2}'`

# 解析参数
parse_command_options $*

# 绑定云中心账号
if [ ! -z "$cloud_name" ] && [ ! -z "$cloud_passwd" ];then
	bind_cloud_account $cloud_name $cloud_passwd
fi

# 更新监听端口
if [ ! -z "$update_port" ];then
	update_listen_port $update_port
fi

# 添加监听端口
if [ ! -z "$insert_port" ];then
	insert_listen_port $insert_port
fi

# 删除监听端口
if [ ! -z "$delete_port" ];then
	delete_listen_port
fi

# 设置代理服务器
if [ ! -z "$proxy_ip" ];then
	update_proxy_server $proxy_ip
fi

# 添加自定义的apache模块
if [ ! -z "$apache_version" ];then
	o=`echo $apache_version | awk -F":" '{print $1}'`
	n=`echo $apache_version | awk -F":" '{print $2}'`
	
	create_special_apache_module $o $n
fi

# 创建新的machine id
if [ ! -z "$new_machine_id" ];then
	! test -d /etc/.markmid && mkdir /etc/.markmid
	echo `date +%s` | md5sum | awk '{printf $1}' > /etc/.markmid/markmid.conf
fi
